@@ -1,11 +1,16 @@
 #[cfg(feature = "cc")]
 use cc::Build;
 use std::env::var;
+use std::io::Write;
 
 /// The directory for out-of-line ("outline") libraries.
 const OUTLINE_PATH: &str = "src/imp/linux_raw/arch/outline";
 
 fn main() {
+    // Don't rerun this on changes other than build.rs, as we only depend on
+    // the rustc version.
+    println!("cargo:rerun-if-changed=build.rs");
+
     let arch = var("CARGO_CFG_TARGET_ARCH").unwrap();
     let asm_name = format!("{}/{}.S", OUTLINE_PATH, arch);
     let os_name = var("CARGO_CFG_TARGET_OS").unwrap();
@@ -19,24 +24,17 @@ fn main() {
         || std::fs::metadata(&asm_name).is_err()
         || is_x32
     {
-        println!("cargo:rustc-cfg=libc");
+        use_feature("libc");
     } else {
-        println!("cargo:rustc-cfg=linux_raw");
+        use_feature("linux_raw");
 
-        if let rustc_version::Channel::Nightly = rustc_version::version_meta()
-            .expect("query rustc release channel")
-            .channel
-        {
-            println!("cargo:rustc-cfg=linux_raw_inline_asm");
-            println!("cargo:rustc-cfg=rustc_attrs");
-            println!("cargo:rustc-cfg=core_intrinsics");
-            println!("cargo:rustc-cfg=doc_cfg");
-        } else {
+        use_feature_or_nothing("rustc_attrs");
+        use_feature_or_nothing("core_intrinsics");
+        use_feature_or_nothing("doc_cfg");
+
+        use_feature_or_else("asm", || {
             link_in_librustix_outline(&arch, &asm_name);
-        }
-        if rustc_version::version().unwrap() >= rustc_version::Version::parse("1.56.0").unwrap() {
-            println!("cargo:rustc-cfg=const_fn_union");
-        }
+        });
     }
     println!("cargo:rerun-if-env-changed=CARGO_CFG_RUSTIX_USE_LIBC");
 }
@@ -83,3 +81,41 @@ fn link_in_librustix_outline(arch: &str, asm_name: &str) {
         );
     }
 }
+
+fn use_feature_or_nothing(feature: &str) {
+    if has_feature(feature) {
+        use_feature(feature);
+    }
+}
+
+fn use_feature_or_else<F: FnOnce()>(feature: &str, or_else: F) {
+    if has_feature(feature) {
+        use_feature(feature);
+    } else {
+        or_else();
+    }
+}
+
+fn use_feature(feature: &str) {
+    println!("cargo:rustc-cfg={}", feature);
+}
+
+/// Test whether the rustc at `var("RUSTC")` supports the given feature.
+fn has_feature(feature: &str) -> bool {
+    let out_dir = var("OUT_DIR").unwrap();
+    let rustc = var("RUSTC").unwrap();
+
+    let mut child = std::process::Command::new(rustc)
+        .arg("--crate-type=rlib") // Don't require `main`.
+        .arg("--emit=metadata") // Do as little as possible but still parse.
+        .arg("--out-dir")
+        .arg(out_dir) // Put the output somewhere inconsequential.
+        .arg("-") // Read from stdin.
+        .stdin(std::process::Stdio::piped()) // Stdin is a pipe.
+        .spawn()
+        .unwrap();
+
+    writeln!(child.stdin.take().unwrap(), "#![feature({})]", feature).unwrap();
+
+    child.wait().unwrap().success()
+}
